.. _api_hooks:

User Hooks (:mod:`pydicom.hooks`)
=================================

.. module:: pydicom.hooks
.. currentmodule:: pydicom.hooks

Hooks manager class and instance

.. autosummary::
   :toctree: generated/

   hooks
   Hooks


Hooks for :func:`~pydicom.dataelem.convert_raw_data_element`

.. autosummary::
   :toctree: generated/

   raw_element_vr
   raw_element_value
   raw_element_value_fix_separator
   raw_element_value_retry
